#INCLUDE "PROTHEUS.CH"
#INCLUDE "REPORT.CH"
#include 'fileio.ch'

//-------------------------------------------------------------------
/*/{Protheus.doc}FISR220
Relatrio de conferncia das notas fiscais consideradas na composio do coeficiente
de aropriaoapropriao do CIAP, por meio da configurao dos CFOPs e CSTs.

@author Erick G Dias
@since 14/03/2019
@version P12.1.23

/*/
//-------------------------------------------------------------------
User Function UNI220()

	Local oReport
	Local cMsg      := ""
	Local ccAlias   := getNextAlias()
	Local ccAlias2  := getNextAlias()

	If AliasIndic("F1F") .AND. AliasIndic("F1G")
		If Pergunte("UNI220",.T.)
			cMsg    := ChkPerg()
			If Empty(cMsg)
				oReport := ReportDef(ccAlias, ccAlias2,  "UNI220")
				oReport:PrintDialog()

				If Select(ccAlias) > 0
					dbSelectArea(ccAlias)
					(ccAlias)->(DbCloseArea())
				EndIf
				If Select(ccAlias2) > 0
					dbSelectArea(ccAlias2)
					(ccAlias2)->(DbCloseArea())
				EndIf

			Else
				MsgAlert(cMsg)
			EndIF

		EndIF

	EndIF

Return

//-------------------------------------------------------------------
/*/{Protheus.doc}ReportDef

Funo que montar a estrutura do relatrio

@author Erick G Dias
@since 14/03/2019
@version P12.1.23

/*/
//-------------------------------------------------------------------
Static Function ReportDef(ccAlias, ccAlias2, cPerg )

	Local oReport
	Local oSection1
	Local oSection2
	Local oSection3
	Local cTitle    := "Conferncia de notas fiscais consideradas para compor coeficiente de apropriao do CIAP"
	Local oBreak1   := Nil
	Local nBorder    := 1 //superior
	Local nBorder4   := 4 //direita
	Local cMtdCoef  := Alltrim(GetNewPar ("MV_MTDCOEF",""))
	Local cDivCoef	:= GetNewPar ("MV_DIVCOEF","1")
	Default ccAlias   := getNextAlias()
	Default ccAlias2   := getNextAlias()

	oReport	:= TReport():New('UNI220', cTitle ,cPerg,{|oReport|ReportPrint(oReport,ccAlias,ccAlias2, MV_PAR01)},'')
	oReport:SetLandScape()
	oReport:HideParamPage()
	oReport:SetLineHeight(40)

	oSection1 := TRSection():New( oReport, "Operando do Coeficiente CIAP", {"F1F"} ) //"Operando do Coeficiente CIAP"
	oSection1:SetPageBreak(.T.)
	oSection1:SetBorder(2)

//Seo 1 - Operando
	TRCell():New(oSection1,"F1F_FILIAL", "F1F", "Filial") //"Filial"
	TRCell():New(oSection1,"F1F_OPERAN", "F1F", "Operando CIAP") //"Operando CIAP"
	TRCell():New(oSection1,"F1G_VLORIG", "F1F", "Valor Origem") //"Valor Origem"
	TRCell():New(oSection1,"",  "", "","@!",170)

// Seo 2 - Documentos Fiscais
	oSection2 := TRSection():New(oSection1 , "Notas Fiscais", {"SFT"})//"Tributos por Documentos Fiscais"
	TRCell():New(oSection2,"FT_NFISCAL", "SFT", "Nmero NF")//"Nmero NF"
	TRCell():New(oSection2,"FT_SERIE",	 "SFT", "Srie NF") //"Srie NF"
	TRCell():New(oSection2,"FT_CFOP",    "SFT", "CFOP")//"CFOP"
	TRCell():New(oSection2,"FT_CLIEFOR", "SFT", "Cod. Participante")//"Cod. Participante"
	TRCell():New(oSection2,"FT_LOJA",	 "SFT", "Loja Participante")//"Loja Participante"
	TRCell():New(oSection2,"FT_EMISSAO", "SFT", "Data") //"Data"
	TRCell():New(oSection2,"FT_ITEM",	 "SFT", "Item NF")//"Item NF"
	TRCell():New(oSection2,"FT_CLASFIS", "SFT", "CST ICMS")//"CST ICMS"
	TRCell():New(oSection2,"FT_VALCONT", "SFT", "Valor Contbil")//"Valor Contbil"
	TRCell():New(oSection2,"FT_TOTAL"  , "SFT", "Valor Mercadoria")//"Valor Mercadoria"
	TRCell():New(oSection2,"FT_BASEICM", "SFT", "Base ICMS")//"Base ICMS"
	TRCell():New(oSection2,"FT_ISENICM", "SFT", "Isento")//"Isento"
	TRCell():New(oSection2,"FT_OUTRICM", "SFT", "Outros")//"Outros"
	TRCell():New(oSection2,"VALORIGEM",    "" , "Valor de Origem","@E 99,999,999,999.99",14,,{||MTA906VOPE((ccAlias)->F1G_VLORIG, (ccAlias)->FT_VALCONT, (ccAlias)->FT_TOTAL, (ccAlias)->FT_ISENICM , (ccAlias)->FT_OUTRICM , (ccAlias)->FT_BASEICM)}) //"Valor de Origem"

//Insere linha superior no cabealho
	oSection2:Cell("FT_NFISCAL"):SetBorder(nBorder,1,000000,.T.)
	oSection2:Cell("FT_SERIE"):SetBorder(nBorder,1,000000,.T.)
	oSection2:Cell("FT_CFOP"):SetBorder(nBorder,1,000000,.T.)
	oSection2:Cell("FT_CLIEFOR"):SetBorder(nBorder,1,000000,.T.)
	oSection2:Cell("FT_LOJA"):SetBorder(nBorder,1,000000,.T.)
	oSection2:Cell("FT_EMISSAO"):SetBorder(nBorder,1,000000,.T.)
	oSection2:Cell("FT_ITEM"):SetBorder(nBorder,1,000000,.T.)
	oSection2:Cell("FT_CFOP"):SetBorder(nBorder,1,000000,.T.)
	oSection2:Cell("FT_CLASFIS"):SetBorder(nBorder,1,000000,.T.)
	oSection2:Cell("FT_VALCONT"):SetBorder(nBorder,1,000000,.T.)
	oSection2:Cell("FT_TOTAL"):SetBorder(nBorder,1,000000,.T.)
	oSection2:Cell("FT_BASEICM"):SetBorder(nBorder,1,000000,.T.)
	oSection2:Cell("FT_ISENICM"):SetBorder(nBorder,1,000000,.T.)
	oSection2:Cell("FT_OUTRICM"):SetBorder(nBorder,1,000000,.T.)
	oSection2:Cell("VALORIGEM"):SetBorder(nBorder,1,000000,.T.)

//Insere linha na direita no cabealho
	oSection2:Cell("FT_NFISCAL"):SetBorder(nBorder4,1,000000,.T.)
	oSection2:Cell("FT_SERIE"):SetBorder(nBorder4,1,000000,.T.)
	oSection2:Cell("FT_CFOP"):SetBorder(nBorder4,1,000000,.T.)
	oSection2:Cell("FT_CLIEFOR"):SetBorder(nBorder4,1,000000,.T.)
	oSection2:Cell("FT_LOJA"):SetBorder(nBorder4,1,000000,.T.)
	oSection2:Cell("FT_EMISSAO"):SetBorder(nBorder4,1,000000,.T.)
	oSection2:Cell("FT_ITEM"):SetBorder(nBorder4,1,000000,.T.)
	oSection2:Cell("FT_CFOP"):SetBorder(nBorder4,1,000000,.T.)
	oSection2:Cell("FT_CLASFIS"):SetBorder(nBorder4,1,000000,.T.)
	oSection2:Cell("FT_VALCONT"):SetBorder(nBorder4,1,000000,.T.)
	oSection2:Cell("FT_TOTAL"):SetBorder(nBorder4,1,000000,.T.)
	oSection2:Cell("FT_BASEICM"):SetBorder(nBorder4,1,000000,.T.)
	oSection2:Cell("FT_ISENICM"):SetBorder(nBorder4,1,000000,.T.)
	oSection2:Cell("FT_OUTRICM"):SetBorder(nBorder4,1,000000,.T.)

//Insere linha na direita nas linhas
	oSection2:Cell("FT_NFISCAL"):SetBorder(nBorder4,1,000000,.F.)
	oSection2:Cell("FT_SERIE"):SetBorder(nBorder4,1,000000,.F.)
	oSection2:Cell("FT_CFOP"):SetBorder(nBorder4,1,000000,.F.)
	oSection2:Cell("FT_CLIEFOR"):SetBorder(nBorder4,1,000000,.F.)
	oSection2:Cell("FT_LOJA"):SetBorder(nBorder4,1,000000,.F.)
	oSection2:Cell("FT_EMISSAO"):SetBorder(nBorder4,1,000000,.F.)
	oSection2:Cell("FT_ITEM"):SetBorder(nBorder4,1,000000,.F.)
	oSection2:Cell("FT_CFOP"):SetBorder(nBorder4,1,000000,.F.)
	oSection2:Cell("FT_CLASFIS"):SetBorder(nBorder4,1,000000,.F.)
	oSection2:Cell("FT_VALCONT"):SetBorder(nBorder4,1,000000,.F.)
	oSection2:Cell("FT_TOTAL"):SetBorder(nBorder4,1,000000,.F.)
	oSection2:Cell("FT_BASEICM"):SetBorder(nBorder4,1,000000,.F.)
	oSection2:Cell("FT_ISENICM"):SetBorder(nBorder4,1,000000,.F.)
	oSection2:Cell("FT_OUTRICM"):SetBorder(nBorder4,1,000000,.F.)

//Alinhamento centralizado
	oSection2:Cell("FT_NFISCAL"):nAlign := 2
	oSection2:Cell("FT_SERIE"):nAlign := 2
	oSection2:Cell("FT_CFOP"):nAlign := 2
	oSection2:Cell("FT_CLIEFOR"):nAlign := 2
	oSection2:Cell("FT_EMISSAO"):nAlign := 2
	oSection2:Cell("FT_LOJA"):nAlign := 2
	oSection2:Cell("FT_ITEM"):nAlign := 2
	oSection2:Cell("FT_CLASFIS"):nAlign := 2
	oSection2:SetAutoSize(.T.)

	oBreak1 := TRBreak():New(oSection1,{|| (ccAlias)->(F1F_OPERAN) + (ccAlias)->(F1G_VLORIG)   },"Valor" ,.F.,"Valor" ,.T.) //'Total da Regra por Operao NF' //'Total da Regra por Operao NF '
	TRFunction():New(oSection2:Cell("VALORIGEM") ,  ,"SUM", oBreak1,"Valor" ,/*cPicture*/,/*uFormula*/,.F./*lEndSection*/,.F./*lEndReport*/,.T./*lEndPage*/) //"Valor"
	oSection2:SetHeaderBreak(.T.) //Imprime cabealho das clulas aps quebra
	oSection2:SetHeaderSection(.T.)

	oSection3 := TRSection():New( oReport, "Operando do Coeficiente CIAP (Devolues)", {"F1F"} ) //"Operando do Coeficiente CIAP (Devolues)"
	oSection3:SetPageBreak(.T.)
	oSection3:SetBorder(2)

//Seo 1 - Operando
	TRCell():New(oSection3,"F1F_FILIAL", "F1F", "Filial") //"Filial"
	TRCell():New(oSection3,"F1F_OPERAN", "F1F", "Operando CIAP") //"Operando CIAP"
	TRCell():New(oSection3,"F1G_VLORIG", "F1F", "Valor Origem") //"Valor Origem"
	TRCell():New(oSection3,"",  "", "","@!",170)

// Seo 2 - Documentos Fiscais
	oSection4 := TRSection():New(oSection3 , "Notas Fiscais", {"SFT"})//"Tributos por Documentos Fiscais"
	TRCell():New(oSection4,"FT_NFISCAL", "SFT", "Nmero NF")//"Nmero NF"
	TRCell():New(oSection4,"FT_SERIE",	 "SFT", "Srie NF") //"Srie NF"
	TRCell():New(oSection4,"FT_CFOP",    "SFT", "CFOP")//"CFOP"
	TRCell():New(oSection4,"FT_CLIEFOR", "SFT", "Cod. Participante")//"Cod. Participante"
	TRCell():New(oSection4,"FT_LOJA",	 "SFT", "Loja Participante")//"Loja Participante"
	TRCell():New(oSection4,"FT_EMISSAO", "SFT", "Data") //"Data"
	TRCell():New(oSection4,"FT_ITEM",	 "SFT", "Item NF")//"Item NF"
	TRCell():New(oSection4,"FT_CLASFIS", "SFT", "CST ICMS")    //"CST ICMS"
	TRCell():New(oSection4,"FT_VALCONT", "SFT", "Valor Contbil")//"Valor Contbil"
	TRCell():New(oSection4,"FT_TOTAL"  , "SFT", "Valor Mercadoria")//"Valor Mercadoria"
	TRCell():New(oSection4,"FT_BASEICM", "SFT", "Base ICMS")//"Base ICMS"
	TRCell():New(oSection4,"FT_ISENICM", "SFT", "Isento")//"Isento"
	TRCell():New(oSection4,"FT_OUTRICM", "SFT", "Outros")//"Outros"
	TRCell():New(oSection4,"VALORIGEM",    "" , "Valor de Origem","@E 99,999,999,999.99",14,,{||MTA906VOPE((ccAlias2)->F1G_VLORIG, (ccAlias2)->FT_VALCONT, (ccAlias2)->FT_TOTAL, (ccAlias2)->FT_ISENICM , (ccAlias2)->FT_OUTRICM , (ccAlias2)->FT_BASEICM)}) //"Valor de Origem"

//Insere linha superior no cabealho
	oSection4:Cell("FT_NFISCAL"):SetBorder(nBorder,1,000000,.T.)
	oSection4:Cell("FT_SERIE"):SetBorder(nBorder,1,000000,.T.)
	oSection4:Cell("FT_CFOP"):SetBorder(nBorder,1,000000,.T.)
	oSection4:Cell("FT_CLIEFOR"):SetBorder(nBorder,1,000000,.T.)
	oSection4:Cell("FT_LOJA"):SetBorder(nBorder,1,000000,.T.)
	oSection4:Cell("FT_EMISSAO"):SetBorder(nBorder,1,000000,.T.)
	oSection4:Cell("FT_ITEM"):SetBorder(nBorder,1,000000,.T.)
	oSection4:Cell("FT_CFOP"):SetBorder(nBorder,1,000000,.T.)
	oSection4:Cell("FT_CLASFIS"):SetBorder(nBorder,1,000000,.T.)
	oSection4:Cell("FT_VALCONT"):SetBorder(nBorder,1,000000,.T.)
	oSection4:Cell("FT_TOTAL"):SetBorder(nBorder,1,000000,.T.)
	oSection4:Cell("FT_BASEICM"):SetBorder(nBorder,1,000000,.T.)
	oSection4:Cell("FT_ISENICM"):SetBorder(nBorder,1,000000,.T.)
	oSection4:Cell("FT_OUTRICM"):SetBorder(nBorder,1,000000,.T.)
	oSection4:Cell("VALORIGEM"):SetBorder(nBorder,1,000000,.T.)

//Insere linha na direita no cabealho
	oSection4:Cell("FT_NFISCAL"):SetBorder(nBorder4,1,000000,.T.)
	oSection4:Cell("FT_SERIE"):SetBorder(nBorder4,1,000000,.T.)
	oSection4:Cell("FT_CFOP"):SetBorder(nBorder4,1,000000,.T.)
	oSection4:Cell("FT_CLIEFOR"):SetBorder(nBorder4,1,000000,.T.)
	oSection4:Cell("FT_LOJA"):SetBorder(nBorder4,1,000000,.T.)
	oSection4:Cell("FT_EMISSAO"):SetBorder(nBorder4,1,000000,.T.)
	oSection4:Cell("FT_ITEM"):SetBorder(nBorder4,1,000000,.T.)
	oSection4:Cell("FT_CFOP"):SetBorder(nBorder4,1,000000,.T.)
	oSection4:Cell("FT_CLASFIS"):SetBorder(nBorder4,1,000000,.T.)
	oSection4:Cell("FT_VALCONT"):SetBorder(nBorder4,1,000000,.T.)
	oSection4:Cell("FT_TOTAL"):SetBorder(nBorder4,1,000000,.T.)
	oSection4:Cell("FT_BASEICM"):SetBorder(nBorder4,1,000000,.T.)
	oSection4:Cell("FT_ISENICM"):SetBorder(nBorder4,1,000000,.T.)
	oSection4:Cell("FT_OUTRICM"):SetBorder(nBorder4,1,000000,.T.)

//Insere linha na direita nas linhas
	oSection4:Cell("FT_NFISCAL"):SetBorder(nBorder4,1,000000,.F.)
	oSection4:Cell("FT_SERIE"):SetBorder(nBorder4,1,000000,.F.)
	oSection4:Cell("FT_CFOP"):SetBorder(nBorder4,1,000000,.F.)
	oSection4:Cell("FT_CLIEFOR"):SetBorder(nBorder4,1,000000,.F.)
	oSection4:Cell("FT_LOJA"):SetBorder(nBorder4,1,000000,.F.)
	oSection4:Cell("FT_EMISSAO"):SetBorder(nBorder4,1,000000,.F.)
	oSection4:Cell("FT_ITEM"):SetBorder(nBorder4,1,000000,.F.)
	oSection4:Cell("FT_CFOP"):SetBorder(nBorder4,1,000000,.F.)
	oSection4:Cell("FT_CLASFIS"):SetBorder(nBorder4,1,000000,.F.)
	oSection4:Cell("FT_VALCONT"):SetBorder(nBorder4,1,000000,.F.)
	oSection4:Cell("FT_TOTAL"):SetBorder(nBorder4,1,000000,.F.)
	oSection4:Cell("FT_BASEICM"):SetBorder(nBorder4,1,000000,.F.)
	oSection4:Cell("FT_ISENICM"):SetBorder(nBorder4,1,000000,.F.)
	oSection4:Cell("FT_OUTRICM"):SetBorder(nBorder4,1,000000,.F.)

//Alinhamento centralizado
	oSection4:Cell("FT_NFISCAL"):nAlign := 2
	oSection4:Cell("FT_SERIE"):nAlign := 2
	oSection4:Cell("FT_CFOP"):nAlign := 2
	oSection4:Cell("FT_CLIEFOR"):nAlign := 2
	oSection4:Cell("FT_EMISSAO"):nAlign := 2
	oSection4:Cell("FT_LOJA"):nAlign := 2
	oSection4:Cell("FT_ITEM"):nAlign := 2
	oSection4:Cell("FT_CLASFIS"):nAlign := 2
	oSection4:SetAutoSize(.T.)

	oBreak1 := TRBreak():New(oSection3,{|| (ccAlias2)->(F1F_OPERAN) + (ccAlias2)->(F1G_VLORIG)   },"Valor de Origem (Devoluo)",.F.,"Valor de Origem (Devoluo)",.T.) //'Total da Regra por Operao NF' //'Total da Regra por Operao NF '
	TRFunction():New(oSection4:Cell("VALORIGEM") ,  ,"SUM", oBreak1,"Valor de Origem (Devoluo)" ,/*cPicture*/,/*uFormula*/,.F./*lEndSection*/,.F./*lEndReport*/,.T./*lEndPage*/) //"Valor "
	oSection4:SetHeaderBreak(.T.) //Imprime cabealho das clulas aps quebra
	oSection4:SetHeaderSection(.T.)

//---------------------
//Seo de Totalizador
//---------------------
	oSection5 := TRSection():New( oReport, "Resumo dos Totais" )
	oSection5:SetPageBreak(.T.)
	oSection5:SetBorder(2)

	TRCell():New(oSection5,"A", "", "(A)Tributado","@E 99,999,999,999.99",17)
	TRCell():New(oSection5,"B", "", "(B)Dev. Trib.","@E 99,999,999,999.99",17)
	TRCell():New(oSection5,"C", "", "(C)No Trib.","@E 99,999,999,999.99",14)
	TRCell():New(oSection5,"D", "", "(D)Dev. No Trib.","@E 99,999,999,999.99",17)
	TRCell():New(oSection5,"E", "", "(E)Exp.","@E 99,999,999,999.99",17)
	TRCell():New(oSection5,"F", "", "(F)Dev. Exp.","@E 99,999,999,999.99",17)
	TRCell():New(oSection5,"G", "", "(G)Equip.","@E 99,999,999,999.99",17)
	TRCell():New(oSection5,"H", "", "(H)Dev. Equip.","@E 99,999,999,999.99",17)
	If cDivCoef == "1" .Or. Empty(cDivCoef)
		TRCell():New(oSection5,"I", "", "(I)Tot. Trib=((A-B)+(E-F)+(G-H))","@E 99,999,999,999.99",17)
		TRCell():New(oSection5,"J", "", "(J)Tot. No Trib.=(C-D)","@E 99,999,999,999.99",17)
		TRCell():New(oSection5,"L", "", "(L)Tot. Sadas=(I+J)","@E 99,999,999,999.99",17)
	ElseIf cDivCoef == "2"
		TRCell():New(oSection5,"I", "", "(I)Tot. Trib=((A-B)+(E-F)+(G-H))","@E 99,999,999,999.99",17)
		TRCell():New(oSection5,"J", "", "(J)Tot. No Trib.=(C-D)","@E 99,999,999,999.99",17)
		TRCell():New(oSection5,"L", "", "(L)Tot. Sadas","@E 99,999,999,999.99",17)
	ElseIf cDivCoef == "3"
		TRCell():New(oSection5,"I", "", "(I)Tot. Trib=(A-B)","@E 99,999,999,999.99",17)
		TRCell():New(oSection5,"J", "", "(J)Tot. No Trib.=(C-D)","@E 99,999,999,999.99",17)
		TRCell():New(oSection5,"L", "", "(L)Tot. Sadas","@E 99,999,999,999.99",17)
	EndIf

//Insere linha superior no cabealho
	oSection5:Cell("A"):SetBorder(nBorder,1,000000,.T.)
	oSection5:Cell("B"):SetBorder(nBorder,1,000000,.T.)
	oSection5:Cell("C"):SetBorder(nBorder,1,000000,.T.)
	oSection5:Cell("D"):SetBorder(nBorder,1,000000,.T.)
	oSection5:Cell("E"):SetBorder(nBorder,1,000000,.T.)
	oSection5:Cell("F"):SetBorder(nBorder,1,000000,.T.)
	oSection5:Cell("G"):SetBorder(nBorder,1,000000,.T.)
	oSection5:Cell("H"):SetBorder(nBorder,1,000000,.T.)
	oSection5:Cell("I"):SetBorder(nBorder,1,000000,.T.)
	oSection5:Cell("H"):SetBorder(nBorder,1,000000,.T.)
	oSection5:Cell("J"):SetBorder(nBorder,1,000000,.T.)
	oSection5:Cell("L"):SetBorder(nBorder,1,000000,.T.)

//Insere linha na direita no cabealho
	oSection5:Cell("A"):SetBorder(nBorder4,1,000000,.T.)
	oSection5:Cell("B"):SetBorder(nBorder4,1,000000,.T.)
	oSection5:Cell("C"):SetBorder(nBorder4,1,000000,.T.)
	oSection5:Cell("D"):SetBorder(nBorder4,1,000000,.T.)
	oSection5:Cell("E"):SetBorder(nBorder4,1,000000,.T.)
	oSection5:Cell("F"):SetBorder(nBorder4,1,000000,.T.)
	oSection5:Cell("G"):SetBorder(nBorder4,1,000000,.T.)
	oSection5:Cell("H"):SetBorder(nBorder4,1,000000,.T.)
	oSection5:Cell("I"):SetBorder(nBorder4,1,000000,.T.)
	oSection5:Cell("J"):SetBorder(nBorder4,1,000000,.T.)

//Insere linha na esquerda nas linhas
	oSection5:Cell("A"):SetBorder(nBorder4,1,000000,.F.)
	oSection5:Cell("B"):SetBorder(nBorder4,1,000000,.F.)
	oSection5:Cell("C"):SetBorder(nBorder4,1,000000,.F.)
	oSection5:Cell("D"):SetBorder(nBorder4,1,000000,.F.)
	oSection5:Cell("E"):SetBorder(nBorder4,1,000000,.F.)
	oSection5:Cell("F"):SetBorder(nBorder4,1,000000,.F.)
	oSection5:Cell("G"):SetBorder(nBorder4,1,000000,.F.)
	oSection5:Cell("H"):SetBorder(nBorder4,1,000000,.F.)
	oSection5:Cell("I"):SetBorder(nBorder4,1,000000,.F.)
	oSection5:Cell("J"):SetBorder(nBorder4,1,000000,.F.)

Return oReport

//-------------------------------------------------------------------
/*/{Protheus.doc}ReportPrint

Funo que far a query para obter as informaes

@author Erick G Dias
@since 14/03/2019
@version P12.1.23

/*/
//-------------------------------------------------------------------
static function ReportPrint(oReport, ccAlias,ccAlias2, dDataProc)
	local oSection1b := oReport:Section(1)
	local oSection2b := ''
	local oSection3b := oReport:Section(2)
	local oSection4b := ''
	local oSection5b := oReport:Section(3)
	Local cFiltro    := ''
	Local cMtdCoef   := Alltrim(GetNewPar ("MV_MTDCOEF",""))
	Local dDtIni     := MV_PAR01
	Local dDtFin     := MV_PAR02
	Local nLinPag	 := MV_PAR03
	Local nLinReport := 8

	Local nTotalSai     := 0
	Local nTotTrib      := 0
	Local nTotNaoTrib   := 0
	Local aResumo   :={0,0,0,0,0,0,0,0,0,0}
	Local cDivCoef	:= GetNewPar ("MV_DIVCOEF","1")

	//Local nHnd
	//Local cFile := '\temp\teste.txt'
	//Local cLine , nTamFile
	//Local cNewLine , nRead, nWrote

	If (Empty(mv_par03) .Or. MV_PAR03 > 100)
		nLinPag := 100
	EndIf
//-------------------------------------------------------------------
	oSection2b := oReport:Section(1):Section(1)

	cFiltro = "%"
	cFiltro  += "F1F.F1F_FILIAL = " + ValToSQL( xFilial("F1F") ) + " AND "
	cFiltro  +=	" F1F.F1F_OPERAN IN ('01','03','05','07','09') AND "
	cFiltro  += " F1F.D_E_L_E_T_ = ' ' "
	cFiltro += "  ORDER BY F1F_OPERAN, FT_EMISSAO, FT_CFOP, FT_CLASFIS"
	cFiltro += "%"

	oSection1b:BeginQuery()
	BeginSql Alias ccAlias

    SELECT
        F1F.F1F_FILIAL, F1F.F1F_OPERAN, F1G.F1G_VLORIG,
        SFT.FT_NFISCAL, SFT.FT_SERIE, SFT.FT_CLIEFOR, SFT.FT_LOJA, SFT.FT_EMISSAO, SFT.FT_ITEM, SFT.FT_CFOP, SFT.FT_VALCONT,  SFT.FT_CLASFIS,
        SFT.FT_VALCONT, SFT.FT_TOTAL, SFT.FT_ISENICM, SFT.FT_OUTRICM, SFT.FT_BASEICM
    FROM
        %TABLE:F1F% F1F
        JOIN %Table:F1G% F1G ON( F1G.F1G_FILIAL  = %xFilial:F1G%  AND F1G.F1G_IDCAB = F1F.F1F_ID AND F1G.%NotDel%)        
        JOIN %Table:SFT% SFT ON( SFT.FT_FILIAL  =  %xFilial:SFT%  AND SFT.FT_ENTRADA >= %Exp:DToS(dDtIni)%  AND  SFT.FT_ENTRADA <= %Exp:DToS(dDtFin)% AND SFT.FT_DTCANC = ' ' AND SFT.FT_CFOP = F1G.F1G_CFOP AND SUBSTRING(SFT.FT_CLASFIS,2,2) = F1G.F1G_CST AND SFT.%NotDel%)        

    WHERE
        %Exp:cFiltro%
	EndSql
	oReport:SetTitle("Notas Fiscais Que compoem Coeficiente CIAP")//"Notas Fiscais Que compoem Coeficiente CIAP"
	oSection1b:EndQuery()

	oSection2b:SetParentQuery()

	oSection2b:SetParentFilter({|cParam| (ccAlias)->F1F_OPERAN + (ccAlias)->F1G_VLORIG  == cParam}, {|| (ccAlias)->F1F_OPERAN + (ccAlias)->F1G_VLORIG })

	oReport:SetMeter((ccAlias)->(RecCount()))
	oSection1b:SetTitle("Notas Fiscais Que compoem Coeficiente CIAP")//"Notas Fiscais Que compoem Coeficiente CIAP"
	oSection1b:Print()

//Funo para calcular o resumo dos sub totais
	CalcRes(ccAlias, @aResumo)

//-------------------------------------------------------------------

//-------------------------------------------------------------------
	If cMtdCoef == "1"
		//Esta seo somente ser impressa se o mtodo de composio do coeficiente considerar devolues automticas.
		oSection4b := oReport:Section(2):Section(1)

		cFiltro = "%"
		cFiltro  += "F1F.F1F_FILIAL = " + ValToSQL( xFilial("F1F") ) + " AND "
		If cMtdCoef == "1"
			//Operandos de sada
			//Para este mtodo os operandos de devolues no sero considerados.
			cFiltro  +=	" F1F.F1F_OPERAN IN ('01','03','05','07','09') AND "
		EndIF
		cFiltro  += " F1F.D_E_L_E_T_ = ' ' "
		cFiltro += "  ORDER BY F1F_OPERAN, SFTDEV.FT_EMISSAO, SFTDEV.FT_CFOP, SFTDEV.FT_CLASFIS"
		cFiltro += "%"

		oSection3b:BeginQuery()
		BeginSql Alias ccAlias2

        SELECT
            CASE WHEN F1F.F1F_OPERAN = '01' then '02'
                 WHEN F1F.F1F_OPERAN = '03' then '04'
                 WHEN F1F.F1F_OPERAN = '05' then '06'
                 WHEN F1F.F1F_OPERAN = '07' then '08'
                 WHEN F1F.F1F_OPERAN = '09' then '10'
            END F1F_OPERAN,
            F1F.F1F_FILIAL,  F1G.F1G_VLORIG,
            SFTDEV.FT_NFISCAL, SFTDEV.FT_SERIE, SFTDEV.FT_CLIEFOR, SFTDEV.FT_LOJA, SFTDEV.FT_EMISSAO, SFTDEV.FT_ITEM, SFTDEV.FT_CFOP, SFTDEV.FT_VALCONT,  SFTDEV.FT_CLASFIS,
            SFTDEV.FT_VALCONT, SFTDEV.FT_TOTAL, SFTDEV.FT_ISENICM, SFTDEV.FT_OUTRICM, SFTDEV.FT_BASEICM
        FROM
            %TABLE:F1F% F1F
            JOIN %Table:F1G% F1G ON( F1G.F1G_FILIAL  = %xFilial:F1G%  AND F1G.F1G_IDCAB = F1F.F1F_ID AND F1G.%NotDel%)
            JOIN %Table:SFT% SFTDEV ON( SFTDEV.FT_FILIAL =  %xFilial:SFT% AND SFTDEV.FT_ENTRADA >= %Exp:DToS(dDtIni)%  AND SFTDEV.FT_ENTRADA <= %Exp:DToS(dDtFin)% AND SFTDEV.FT_DTCANC = ' ' AND SFTDEV.FT_TIPOMOV='E' AND SFTDEV.FT_TIPO='D' AND SFTDEV.%NotDel%)
            JOIN %Table:SFT% SFT ON( SFT.FT_FILIAL  =  %xFilial:SFT%  AND SFT.FT_DTCANC = ' ' AND SFT.FT_CFOP = F1G.F1G_CFOP AND SUBSTRING(SFT.FT_CLASFIS,2,2) = F1G.F1G_CST AND SFT.FT_NFISCAL  = SFTDEV.FT_NFORI  AND SFT.FT_SERIE = SFTDEV.FT_SERORI  AND SFT.FT_ITEM = SFTDEV.FT_ITEMORI AND SFT.FT_CLIEFOR = SFTDEV.FT_CLIEFOR AND SFT.FT_LOJA = SFTDEV.FT_LOJA AND SFT.%NotDel%)            

        WHERE
            %Exp:cFiltro%
		EndSql

		oReport:SetTitle("Devolues que compoem o Coeficiente CIAP")//"Devolues que compoem o Coeficiente CIAP"
		oSection3b:EndQuery()

		oSection4b:SetParentQuery()

		oSection4b:SetParentFilter({|cParam| (ccAlias2)->F1F_OPERAN + (ccAlias2)->F1G_VLORIG  == cParam}, {|| (ccAlias2)->F1F_OPERAN + (ccAlias2)->F1G_VLORIG })

		oReport:SetMeter((ccAlias2)->(RecCount()))
		oSection3b:SetTitle("Devolues que compoem o Coeficiente CIAP")//"Devolues que compoem o Coeficiente CIAP"
		oSection3b:Print()

		//Funo para calcular o resumo dos sub totais
		CalcRes(ccAlias2, @aResumo)

	ElseIF cMtdCoef == "2"
		//Apresentar as devolues configuradas

		//Esta seo somente ser impressa se o mtodo de composio do coeficiente considerar devolues automticas.
		oSection4b := oReport:Section(2):Section(1)

		cFiltro = "%"
		cFiltro  += "F1F.F1F_FILIAL = " + ValToSQL( xFilial("F1F") ) + " AND "
		cFiltro  +=	" F1F.F1F_OPERAN IN ('02','04','06','08','10') AND "
		cFiltro  += " F1F.D_E_L_E_T_ = ' ' "
		cFiltro += "  ORDER BY F1F_OPERAN, FT_EMISSAO, FT_CFOP, FT_CLASFIS"
		cFiltro += "%"


		oSection3b:BeginQuery()
		BeginSql Alias ccAlias2

    SELECT
        F1F.F1F_FILIAL, F1F.F1F_OPERAN, F1G.F1G_VLORIG,
        SFT.FT_NFISCAL, SFT.FT_SERIE, SFT.FT_CLIEFOR, SFT.FT_LOJA, SFT.FT_EMISSAO, SFT.FT_ITEM, SFT.FT_CFOP, SFT.FT_VALCONT,  SFT.FT_CLASFIS,
        SFT.FT_VALCONT, SFT.FT_TOTAL, SFT.FT_ISENICM, SFT.FT_OUTRICM, SFT.FT_BASEICM
    FROM
        %TABLE:F1F% F1F
        JOIN %Table:F1G% F1G ON( F1G.F1G_FILIAL  = %xFilial:F1G%  AND F1G.F1G_IDCAB = F1F.F1F_ID AND F1G.%NotDel%)        
        JOIN %Table:SFT% SFT ON( SFT.FT_FILIAL  =  %xFilial:SFT%  AND SFT.FT_ENTRADA >= %Exp:DToS(dDtIni)%  AND  SFT.FT_ENTRADA <= %Exp:DToS(dDtFin)% AND SFT.FT_DTCANC = ' ' AND SFT.FT_TIPOMOV='E' AND SFT.FT_TIPO='D' AND SFT.FT_CFOP = F1G.F1G_CFOP AND SUBSTRING(SFT.FT_CLASFIS,2,2) = F1G.F1G_CST AND SFT.%NotDel%)                

    WHERE
        %Exp:cFiltro%
		EndSql

		oReport:SetTitle("Devolues que compoem o Coeficiente CIAP")//"Devolues que compoem o Coeficiente CIAP"
		oSection3b:EndQuery()

		oSection4b:SetParentQuery()

		oSection4b:SetParentFilter({|cParam| (ccAlias2)->F1F_OPERAN + (ccAlias2)->F1G_VLORIG  == cParam}, {|| (ccAlias2)->F1F_OPERAN + (ccAlias2)->F1G_VLORIG })

		oReport:SetMeter((ccAlias2)->(RecCount()))
		oSection3b:SetTitle("Devolues que compoem o Coeficiente CIAP")//"Devolues que compoem o Coeficiente CIAP"
		oSection3b:Print()

		//Funo para calcular o resumo dos sub totais
		CalcRes(ccAlias2, @aResumo)

	EndIF

//Seo do resumo ser impressa manualmente
	oSection5b:Init()
	oReport:SetTitle("Resumo dos Totais")
	oReport:OnPrintLine( {|| U220LinPag(nLinPag, @nLinReport)})

	nTotNaoTrib   := Max(aResumo[3] - aResumo[4], 0)
	If cDivCoef == "1" .Or. Empty(cDivCoef)
		nTotTrib      := Max((aResumo[1] + aResumo[5] + aResumo[7]) - (aResumo[2] + aResumo[6] + aResumo[8]), 0)
		nTotalSai   := nTotTrib + nTotNaoTrib
	ElseIf cDivCoef == "2"
		nTotTrib      := Max((aResumo[1] + aResumo[5] + aResumo[7]) - (aResumo[2] + aResumo[6] + aResumo[8]), 0)
		nTotalSai   := (aResumo[9] - aResumo[10])
	ElseIf cDivCoef == "3"
		nTotTrib      := Max((aResumo[1]) - (aResumo[2]), 0)
		nTotalSai   := (aResumo[9] - aResumo[10])
	EndIf

	oSection5b:Cell("A"):SetValue(aResumo[1])//VAlor Tributado
	oSection5b:Cell("B"):SetValue(aResumo[2])//Devolues de vendas tributadas
	oSection5b:Cell("C"):SetValue(aResumo[3])//Sadas No tributadas
	oSection5b:Cell("D"):SetValue(aResumo[4])//Devolues de vendas No Tributadas
	oSection5b:Cell("E"):SetValue(aResumo[5])//Exportaes
	oSection5b:Cell("F"):SetValue(aResumo[6])//Devolues das Exportaes
	oSection5b:Cell("G"):SetValue(aResumo[7])//Exportaes Equiparadas
	oSection5b:Cell("H"):SetValue(aResumo[8])//Devolues das exportaes equiparadas
	oSection5b:Cell("I"):SetValue(nTotTrib ) //Total tributado
	oSection5b:Cell("J"):SetValue(nTotNaoTrib)//Total no tributado.
	oSection5b:Cell("L"):SetValue(nTotalSai)//Total Sadas

	oSection5b:PrintLine()
	oSection5b:Finish()

Return

//-------------------------------------------------------------------
/*/{Protheus.doc}ChkPerg

Funo que far as devidas validaes dos parmetros iniciais

@author Erick G Dias
@since 14/03/2019
@version P12.1.23

/*/
//-------------------------------------------------------------------
Static Function ChkPerg()

	Local cRet  := ""

	Do Case
	Case Empty(MV_PAR01)
		cRet    := "Obrigatrio informar a data"//"Obrigatrio informar a data"
	EndCase

Return cRet


Static Function CalcRes(cAlsNF, aResumo)
	Local nValor    := 0

	(cAlsNF)->(DbGoTop ())
	Do While !(cAlsNF)->(Eof())

		nValor  := MTA906VOPE((cAlsNF)->F1G_VLORIG, (cAlsNF)->FT_VALCONT, (cAlsNF)->FT_TOTAL, (cAlsNF)->FT_ISENICM , (cAlsNF)->FT_OUTRICM , (cAlsNF)->FT_BASEICM)

		If (cAlsNF)->F1F_OPERAN == "01"
			aResumo[1]  += nValor
		ElseIf (cAlsNF)->F1F_OPERAN == "02"
			aResumo[2]  += nValor
		ElseIf (cAlsNF)->F1F_OPERAN == "03"
			aResumo[3]  += nValor
		ElseIf (cAlsNF)->F1F_OPERAN == "04"
			aResumo[4]  += nValor
		ElseIf (cAlsNF)->F1F_OPERAN == "05"
			aResumo[5]  += nValor
		ElseIf (cAlsNF)->F1F_OPERAN == "06"
			aResumo[6]  += nValor
		ElseIf (cAlsNF)->F1F_OPERAN == "07"
			aResumo[7]  += nValor
		ElseIf (cAlsNF)->F1F_OPERAN == "08"
			aResumo[8]  += nValor
		ElseIf (cAlsNF)->F1F_OPERAN == "09"
			aResumo[9]  += nValor
		ElseIf (cAlsNF)->F1F_OPERAN == "10"
			aResumo[10]  += nValor
		Endif

		(cAlsNF)->(DbSkip ())
	EndDo

Return

//----------------------------------------------------------------
/*/{Protheus.doc}U220LinPag
Faz a quebra de pagina de acordo com o parametro "Linhas 
por Pagina?" (mv_par03) 

@param nLinPag Numero maximo de linhas definido no relatorio
@param nLinReport Contador de linhas impressas no relatorio
@param lLimpa Restaura o contador quando troca a pagina

@return NIL
/*/
//-----------------------------------------------------------------
Static Function U220LinPag(nLinPag, nLinReport, lLimpa)
	Default nLinPag    := 0
	Default nLinReport := 0
	Default lLimpa     := .F.

	If lLimpa
		nLinReport := 9
	Else
		nLinReport++

		If nLinReport > (nLinPag + 8)
			oReport:EndPage()
			nLinReport := 9
		EndIf
	EndIf

Return Nil
